<?php
/**
 * Content wrappers
 *
 *
 * @see 	    http://docs.woothemes.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

?>
<?php if ( apply_filters( 'shrk_woocommerce_page_cover', true )) : ?>
	<div <?php echo apply_filters( 'shrk-page-cover-atts', 'page-cover' ); ?> >
		<header class="page-header">
		<?php if ( is_shop() ) : ?>
			<h1 class="page-title"><?php echo get_the_title( get_option( 'woocommerce_shop_page_id' ) ); ?></h1>
		<?php elseif ( is_product_category() ) : ?>
			<h1 class="page-title"><?php single_term_title(); ?></h1>
		<?php elseif ( is_product_tag() ) : ?>
			<h1 class="page-title"><?php echo esc_html__( 'Tag: ', 'ux-shop' ); ?><span><?php single_term_title(); ?></span></h1>
		<?php elseif ( is_tax() ) : ?>
			<h1 class="page-title"><?php single_term_title(); ?></h1>
		<?php else : ?>
			<h1 class="page-title"><?php the_title(); ?></h1>
		<?php endif; ?>
			<?php do_action( 'shrk-page-cover-header-after' ); ?>
		</header><!-- .entry-header -->
		<?php do_action( 'shrk-page-cover-after' ); ?>
	</div>
	<?php do_action( 'shrk-wrapper-start-after-cover' ); ?>
<?php endif; ?>

<div class="container container-main-content">
	<div class="row">
		<div class="main-content-inner col-12 <?php echo esc_attr(shrk_get_main_inner_class()); ?>">            
